package com.steerinfo.dil.controller;

import com.steerinfo.dil.feign.ColumnDataFeign;
import com.steerinfo.dil.model.AmsSaleOrderMaterial;
import com.steerinfo.dil.service.IAmsSaleOrderMaterialService;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.framework.controller.RESTfulResult;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * AmsSaleOrderMaterial RESTful接口：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-09-06 07:10
 * 类描述
 * 修订历史：
 * 日期：2021-09-06
 * 作者：generator
 * 参考：
 * 描述：AmsSaleOrderMaterial RESTful接口
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@RestController
@RequestMapping("/${api.version}/amssaleordermaterials")
public class AmsSaleOrderMaterialController extends BaseRESTfulController {

    @Autowired
    IAmsSaleOrderMaterialService amsSaleOrderMaterialService;

    @Autowired
    ColumnDataFeign columnDataFeign;

    @Autowired
    ColumnDataUtil columnDataUtil;

    /**
     * 新增销售订单物资信息
     * @param amsSaleOrderMaterial
     * @return
     */
    @ApiOperation(value="新增销售订单物资信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amsSaleOrderMaterial", value = "销售订单物资信息对象", required = false, dataType = "AmsSaleOrderMaterial")
    })
    @PostMapping(value = "/addAmsSaleOrderMaterial")
    public RESTfulResult addAmsSaleOrderMaterial(@RequestBody(required = false) AmsSaleOrderMaterial amsSaleOrderMaterial){
        int i = amsSaleOrderMaterialService.addAmsSaleOrderMaterial(amsSaleOrderMaterial);
        return success(i);
    }

    /**
     * 通过主键渲染销售订单物资信息
     * @param saleOrderMaterialId
     * @return
     */
    @ApiOperation(value="通过主键渲染销售订单物资信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "saleOrderMaterialId", value = "主键Id", required = false, dataType = "java.math.BigDecimal")
    })
    @PostMapping(value = "/getAmsSaleOrderMaterialBySaleOrderMaterialId")
    public RESTfulResult getAmsSaleOrderMaterialBySaleOrderMaterialId(@RequestParam BigDecimal saleOrderMaterialId){
        List<Map<String, Object>> maps = amsSaleOrderMaterialService.selectBySaleOrderMaterialId(saleOrderMaterialId);
        return success(maps);
    }

    /**
     * 通过主键修改销售订单物资信息
     * @param amsSaleOrderMaterial
     * @return
     */
    @ApiOperation(value="通过主键修改销售订单物资信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amsSaleOrderMaterial", value = "销售订单物资信息对象", required = false, dataType = "AmsSaleOrderMaterial")
    })
    @PostMapping(value = "/updateAmsSaleOrderMaterial")
    public RESTfulResult updateAmsSaleOrderMaterial(@RequestBody(required = false) AmsSaleOrderMaterial amsSaleOrderMaterial){
        int i = amsSaleOrderMaterialService.updateAmsSaleOrderMaterial(amsSaleOrderMaterial);
        return success(i);
    }

    /**
     * 通过主键删除销售订单物资信息
     * @param saleOrderMaterialId
     * @return
     */
    @ApiOperation(value="通过主键删除销售订单物资信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "saleOrderMaterialId", value = "主键Id", required = false, dataType = "java.math.BigDecimal")
    })
    @PostMapping(value = "/deleteAmsSaleOrderMaterialBySaleOrderMaterialId")
    public RESTfulResult deleteAmsSaleOrderMaterialBySaleOrderMaterialId(BigDecimal saleOrderMaterialId){
        int i = amsSaleOrderMaterialService.deleteAmsSaleOrderMaterialBySaleOrderMaterialId(saleOrderMaterialId);
        return success(i);
    }

    /**
     * 通过主键获取收货地址
     * @param saleOrderMaterialId
     * @return
     */
    @ApiOperation(value="通过主键获取收货地址")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "saleOrderMaterialId", value = "主键Id", required = false, dataType = "java.math.BigDecimal")
    })
    @PostMapping(value = "/getAddress")
    public RESTfulResult getAddress(@RequestParam BigDecimal saleOrderMaterialId){
        String address = amsSaleOrderMaterialService.getAddress(saleOrderMaterialId);
        return success(address);
    }

    /**
     * 通过主键修改销售订单信息(新增一条），过去的成为历史记录
     * @param map
     * @return
     */
    @ApiOperation(value="通过主键修改销售订单信息(新增一条），过去的成为历史记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "map", value = "销售订单物资信息map", required = false, dataType = "java.util.Map")
    })
    @PostMapping(value = "/updateAddress")
    public RESTfulResult updateAddress(@RequestBody(required = false) Map<String,Object> map){
        int i = amsSaleOrderMaterialService.updateAddress(map);
        return success(i);
    }

    /**
     * 获取收货地址
     * @param
     * @return
     */
    @ApiOperation(value="获取收货地址")
    @ApiImplicitParams({
    })
    @GetMapping(value = "/getAddressDeliveryAddress")
    public RESTfulResult getAddressDeliveryAddress(){
        return success(amsSaleOrderMaterialService.getAddressDeliveryAddress());
    }
}
